@@ -21,7 +21,7 @@
 #define MBOXGREP_H
 
 #define APPNAME "mboxgrep"
-#define VERSION "0.7.11"
+#define VERSION "0.7.12a"
 #define BUGREPORT_ADDR "dspiljar AT datatipp.se"
 
 #define HOST_NAME_SIZE 256
@@ -46,34 +46,46 @@
 
 typedef enum
   {
-    MBOX,
-    ZMBOX,
-    MH,
-    NNML,
-    NNMH,
-    MAILDIR,
-    BZ2MBOX
+    FORMAT_UNDEF,
+    FORMAT_MBOX,
+    FORMAT_ZMBOX,
+    FORMAT_MH,
+    FORMAT_NNML,
+    FORMAT_NNMH,
+    FORMAT_MAILDIR,
+    FORMAT_BZ2MBOX
   }
 format_t;
 
 typedef enum
   {
-    NONE,
-    FCNTL,
-    FLOCK
+    LOCK_UNDEF,
+    LOCK_NONE,
+    LOCK_FCNTL,
+    LOCK_FLOCK
   }
 lockmethod_t;
 
 typedef enum
   {
-    DISPLAY,
-    WRITE,
-    COUNT,
-    DELETE,
-    PIPE
+    ACTION_UNDEF,
+    ACTION_DISPLAY,
+    ACTION_WRITE,
+    ACTION_COUNT,
+    ACTION_DELETE,
+    ACTION_PIPE
   }
 action_t;
 
+typedef enum
+  {
+    REGEX_UNDEF,
+    REGEX_BASIC,
+    REGEX_EXTENDED,
+    REGEX_PERL
+  }
+regextype_t;
+
 typedef struct
 {
   FILE *fp;
@@ -93,9 +105,6 @@ checksum_t;
 
 typedef struct
 {
-  int extended;
-  int perl;
-  
   int body;
   int headers;
   int dedup;
@@ -111,12 +120,13 @@ typedef struct
   char hostname[HOST_NAME_SIZE];
   char *boxname, *outboxname, *pipecmd, *tmpfilename, *regex_s;
 
-  void *pcre_pattern, *pcre_hints, *posix_pattern;
+  void *pcre_pattern, *posix_pattern, *match_data;
   int res1, res2;
 
   action_t action;
   format_t format;
   lockmethod_t lock;
+  regextype_t regextype;
 }
 option_t;
 
